@@ -1,3 +1,5 @@
+# frozen_string_literal: true
+
 # Copyright, 2017, by Samuel G. D. Williams. <http://www.codeotaku.com>
 # 
 # Permission is hereby granted, free of charge, to any person obtaining a copy
@@ -22,10 +24,5 @@ require 'console'
 require_relative 'task'
 
 module Async
-	# @return the current logger, either the active tasks logger, or the global event console logger.
-	def self.logger
-		if task = Task.current?
-			task.logger
-		end || Console.logger
-	end
+	extend Console
 end
