@@ -1,3 +1,5 @@
+# frozen_string_literal: true
+
 # Copyright, 2017, by Samuel G. D. Williams. <http://www.codeotaku.com>
 # 
 # Permission is hereby granted, free of charge, to any person obtaining a copy
@@ -24,9 +26,12 @@ module Kernel
 	# Run the given block of code synchronously, but within a reactor if not already in one.
 	def Sync(&block)
 		if task = ::Async::Task.current?
-			yield
+			yield task
 		else
-			::Async::Reactor.run(&block).wait
+			::Async::Reactor.run(
+				finished: ::Async::Condition.new,
+				&block
+			).wait
 		end
 	end
 end
